<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>App.About</name>
    <message>
        <location filename="../main.cpp" line="101"/>
        <location filename="../main.cpp" line="105"/>
        <source>System Monitor</source>
        <translation>Monitor del sistema</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="91"/>
        <source>System Monitor is a tool to monitor realtime system load, view and control processes and services running on your system.</source>
        <translation>Monitor del sistema de Deepin es una herramienta para monitorear la carga del sistema en tiempo real, ver y controlar los procesos y servicios que se ejecutan en su sistema.</translation>
    </message>
</context>
<context>
    <name>BaseDetailViewWidget</name>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="29"/>
        <source>Hide details</source>
        <translation>Ocultar detalles</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="40"/>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="52"/>
        <source>Overall utilization</source>
        <translation>Utilización total</translation>
    </message>
    <message>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="43"/>
        <location filename="../gui/base/base_detail_view_widget.cpp" line="54"/>
        <source>Individual utilization</source>
        <translation>Utilización individual</translation>
    </message>
</context>
<context>
    <name>BlockDevItemWidget</name>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="154"/>
        <source>Read</source>
        <translation>Lectura</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_item_widget.cpp" line="158"/>
        <source>Write</source>
        <translation>Escritura</translation>
    </message>
</context>
<context>
    <name>CPUDetailGrapTableItem</name>
    <message>
        <location filename="../gui/cpu_detail_widget.cpp" line="168"/>
        <location filename="../gui/cpu_detail_widget.cpp" line="285"/>
        <source>60 seconds</source>
        <translation>60 segundos</translation>
    </message>
</context>
<context>
    <name>CPUInfoModel</name>
    <message>
        <location filename="../model/cpu_info_model.cpp" line="49"/>
        <source>%1 days %2 hours %3 minutes</source>
        <translation>%1 días %2 horas %3 minutos</translation>
    </message>
</context>
<context>
    <name>CPUSummaryTableModel</name>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="91"/>
        <source>Utilization</source>
        <translation>Utilización</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="93"/>
        <source>Frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="98"/>
        <source>Max frequency</source>
        <translation>Frequency</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="100"/>
        <source>Average frequency</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="104"/>
        <source>Up time</source>
        <translation>Tiempo de disponibilidad</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="106"/>
        <source>Sockets</source>
        <translation>Zócalos</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="110"/>
        <source>Logical processors</source>
        <translation>Procesadores lógicos</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="112"/>
        <source>Virtualization</source>
        <translation>Virtualización</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="116"/>
        <source>L1i cache</source>
        <translation>Caché L1i</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="118"/>
        <source>L1d cache</source>
        <translation>Caché L1d</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="122"/>
        <source>L2 cache</source>
        <translation>Caché L2</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="124"/>
        <source>L3 cache</source>
        <translation>Caché L3</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="128"/>
        <source>Load average</source>
        <translation>Promedio de carga</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="130"/>
        <source>File descriptors</source>
        <translation>Descriptores de archivo</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="134"/>
        <source>Processes</source>
        <translation>Procesos</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="136"/>
        <source>Threads</source>
        <translation>Hilos</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="140"/>
        <source>Host name</source>
        <translation>Nombre de anfitrión</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="142"/>
        <source>OS type</source>
        <translation>Tipo de sistema</translation>
    </message>
    <message>
        <location filename="../gui/cpu_summary_view_widget.h" line="146"/>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
</context>
<context>
    <name>Cancel</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="310"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
<context>
    <name>ChartViewWidget</name>
    <message>
        <location filename="../gui/chart_view_widget.cpp" line="321"/>
        <source>60 seconds</source>
        <translation>60 segundos</translation>
    </message>
</context>
<context>
    <name>Common.Search</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="493"/>
        <location filename="../gui/system_service_table_view.cpp" line="476"/>
        <source>No search results</source>
        <translation>No hay resultados de búsqueda</translation>
    </message>
</context>
<context>
    <name>CompactCpuMonitor</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="89"/>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>CpuMonitor</name>
    <message>
        <location filename="../cpu_monitor.cpp" line="72"/>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Active.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="165"/>
        <source>active</source>
        <translation>activo</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="167"/>
        <source>reloading</source>
        <translation>recargando</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="169"/>
        <source>inactive</source>
        <translation>inactivo</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="170"/>
        <source>failed</source>
        <translation>falló</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="172"/>
        <source>activating</source>
        <translation>activando</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="174"/>
        <source>deactivating</source>
        <translation>desactivando</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Load.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="146"/>
        <source>stub</source>
        <translation>talón</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="149"/>
        <source>not-found</source>
        <translation>no-encontrado</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="151"/>
        <source>bad-setting</source>
        <translation>mal-ajuste</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="152"/>
        <source>error</source>
        <translation>error</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="153"/>
        <source>merged</source>
        <translation>fusionado</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="154"/>
        <source>masked</source>
        <translation>enmascarado</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="147"/>
        <source>loaded</source>
        <translation>cargado</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Startup.Mode</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="297"/>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="295"/>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="296"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="274"/>
        <source>enabled</source>
        <translation>habilitado</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="275"/>
        <source>disabled</source>
        <translation>inhabilitado</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="276"/>
        <source>static</source>
        <translation>estático</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="277"/>
        <source>transient</source>
        <translation>transitorio</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="278"/>
        <source>indirect</source>
        <translation>indirecto</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="280"/>
        <source>enabled-runtime</source>
        <translation>habilitado-tiempo-de-ejecución</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="281"/>
        <source>masked</source>
        <translation>enmascarado</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="283"/>
        <source>generated</source>
        <translation>generado</translation>
    </message>
</context>
<context>
    <name>DBus.Unit.Sub.State</name>
    <message>
        <location filename="../dbus/dbus_common.h" line="217"/>
        <source>dead</source>
        <translation>muerto</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="219"/>
        <source>start-pre</source>
        <translation>pre-inicio</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="221"/>
        <source>start</source>
        <translation>inicio</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="223"/>
        <source>start-post</source>
        <translation>iniciar-entrada</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="225"/>
        <source>running</source>
        <translation>ejecutando</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="227"/>
        <source>exited</source>
        <translation>salido</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="229"/>
        <source>reload</source>
        <translation>recarga</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="231"/>
        <source>stop</source>
        <translation>alto</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="233"/>
        <source>stop-watchdog</source>
        <translation>detener-perro-guardián</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="235"/>
        <source>stop-sigterm</source>
        <translation>detener-sigterm</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="237"/>
        <source>stop-sigkill</source>
        <translation>detener-sigkill</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="239"/>
        <source>stop-post</source>
        <translation>detener-entrada</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="241"/>
        <source>final-sigterm</source>
        <translation>finalizar-sigterm</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="243"/>
        <source>final-sigkill</source>
        <translation>finalizar-sigkill</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="245"/>
        <source>failed</source>
        <translation>falló</translation>
    </message>
    <message>
        <location filename="../dbus/dbus_common.h" line="247"/>
        <source>auto-restart</source>
        <translation>auto-reinicio</translation>
    </message>
</context>
<context>
    <name>DBusAlarmNotify</name>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="38"/>
        <location filename="../dbus/dbusalarmnotify.cpp" line="50"/>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="39"/>
        <source>Your CPU usage is higher than %1%!</source>
        <translation>¡Su uso de la CPU es superior al %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="51"/>
        <source>Your memory usage is higher than %1%!</source>
        <translation>¡Su uso de memoria es superior al %1%!</translation>
    </message>
    <message>
        <location filename="../dbus/dbusalarmnotify.cpp" line="71"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
</context>
<context>
    <name>DeailTableModel</name>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="67"/>
        <source>Used</source>
        <translation>Usado</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="69"/>
        <source>Available</source>
        <translation>Disponible</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="73"/>
        <source>Shared</source>
        <translation>Compartido</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="75"/>
        <source>Cached</source>
        <translation>En caché</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="79"/>
        <source>Buffers</source>
        <translation>Búferes</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="81"/>
        <source>Cached swap</source>
        <translation>Intercambio en caché</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="85"/>
        <source>Active</source>
        <translation>Activo</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="87"/>
        <source>Inactive</source>
        <translation>Inactivo</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="91"/>
        <source>Dirty</source>
        <translation>Sucio</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="93"/>
        <source>Mapped</source>
        <translation>Mapeado</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="97"/>
        <source>Total swap</source>
        <translation>Intercambio total</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="99"/>
        <source>Free swap</source>
        <translation>Intercambio libre</translation>
    </message>
    <message>
        <location filename="../gui/mem_summary_view_widget.cpp" line="103"/>
        <source>Slab</source>
        <translation>Losa</translation>
    </message>
</context>
<context>
    <name>DeailTableModelBlock</name>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="70"/>
        <source>Model</source>
        <translation>Modelo</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="72"/>
        <source>Read speed</source>
        <translation>Velocidad de lectura</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="76"/>
        <source>Write speed</source>
        <translation>Velocidad de escritura</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="78"/>
        <source>Capacity</source>
        <translation>Capacidad</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="82"/>
        <source>Sectors read</source>
        <translation>Sectores leídos</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="84"/>
        <source>Reads/s</source>
        <translation>Lecturas/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="88"/>
        <source>Sectors read/s</source>
        <translation>Sectores leídos/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="90"/>
        <source>Reads merged/s</source>
        <translation>Lecturas fusionadas/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="94"/>
        <source>Sectors written</source>
        <translation>Sectores escritos</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="96"/>
        <source>Writes completed </source>
        <translation>Escrituras completas</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="100"/>
        <source>Writes merged</source>
        <translation>Escrituras fusionadas</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="102"/>
        <source>Writes/s</source>
        <translation>Escrituras/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="106"/>
        <source>Sectors written/s</source>
        <translation>Sectores escritos/s</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_summary_view_widget.cpp" line="108"/>
        <source>Writes merged/s</source>
        <translation>Escrituras fusionadas/s</translation>
    </message>
</context>
<context>
    <name>Error.Dialog</name>
    <message>
        <location filename="../gui/dialog/error_dialog.cpp" line="73"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>Help.Shortcut.System</name>
    <message>
        <location filename="../common/common.cpp" line="32"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="38"/>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
</context>
<context>
    <name>Kill.Process.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="173"/>
        <source>Ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Terminar este proceso puede causar perdida de datos.
¿Está seguro que quiere continuar?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="530"/>
        <location filename="../gui/process_table_view.cpp" line="172"/>
        <location filename="../gui/process_table_view.cpp" line="379"/>
        <source>End process</source>
        <translation>Terminar proceso</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="380"/>
        <source>Force ending this process may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forzar el cierre del proceso puede causar perdida de datos.
¿Está seguro que quiere continuar?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="531"/>
        <source>Force ending this application may cause data loss.
Are you sure you want to continue?</source>
        <translation>Forzar el cierre de la aplicación puede causar perdida de datos.
¿Está seguro que quiere continuar?</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="539"/>
        <location filename="../gui/process_table_view.cpp" line="179"/>
        <location filename="../gui/process_table_view.cpp" line="387"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="540"/>
        <location filename="../gui/process_table_view.cpp" line="388"/>
        <source>Force End</source>
        <comment>button</comment>
        <translation>Forzar cierre</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="180"/>
        <source>End</source>
        <comment>button</comment>
        <translation>Finalizar</translation>
    </message>
</context>
<context>
    <name>Logout</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="311"/>
        <source>Logout</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../gui/main_window.cpp" line="181"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
</context>
<context>
    <name>MemStatViewWidget</name>
    <message>
        <location filename="../gui/mem_stat_view_widget.cpp" line="52"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
</context>
<context>
    <name>NetInfoDetailItemDelegate</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>IP address:</source>
        <translation>Dirección IP:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Netmask:</source>
        <translation>Máscara de red:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="157"/>
        <source>Broadcast:</source>
        <translation>Emisión:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Prefixlen:</source>
        <translation>Longitud de prefijo:</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="159"/>
        <source>Scope:</source>
        <translation>Alcance:</translation>
    </message>
</context>
<context>
    <name>NetInfoModel</name>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="293"/>
        <source>Connection type</source>
        <translation>Tipo de conexión</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="301"/>
        <source>ESSID</source>
        <translation>ESSID</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="307"/>
        <source>Link quality</source>
        <translation>Calidad de enlace</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="312"/>
        <source>Signal strength</source>
        <translation>Fuerza de la señal</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="317"/>
        <source>Noise level</source>
        <translation>Nivel de ruido</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="323"/>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="328"/>
        <source>Bandwidth</source>
        <translation>Ancho de banda</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="333"/>
        <source>RX packets</source>
        <translation>Paquetes RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="338"/>
        <source>RX bytes</source>
        <translation>Bytes RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="343"/>
        <source>RX errors</source>
        <translation>Errores RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="348"/>
        <source>RX dropped</source>
        <translation>RX abandonados</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="353"/>
        <source>RX overruns</source>
        <translation>RX desbordados</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="358"/>
        <source>RX frame</source>
        <translation>cuadro RX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="363"/>
        <source>TX packets</source>
        <translation>Paquetes TX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="368"/>
        <source>TX bytes</source>
        <translation>Bytes TX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="373"/>
        <source>TX errors</source>
        <translation>Errores TX</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="383"/>
        <source>TX overruns</source>
        <translation>TX desbordados</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="388"/>
        <source>TX carrier</source>
        <translation>TX portadora</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="267"/>
        <location filename="../gui/netif_summary_view_widget.h" line="269"/>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="282"/>
        <location filename="../gui/netif_summary_view_widget.h" line="284"/>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../gui/netif_summary_view_widget.h" line="378"/>
        <source>TX dropped</source>
        <translation>TX cayó</translation>
    </message>
</context>
<context>
    <name>Process.Attributes.Dialog</name>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="143"/>
        <source>Command line</source>
        <translation>Línea de comandos</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="148"/>
        <source>Start time</source>
        <translation>Tiempo de inicio</translation>
    </message>
    <message>
        <location filename="../gui/process_attribute_dialog.cpp" line="138"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
</context>
<context>
    <name>Process.Choose.Window.Dialog</name>
    <message>
        <location filename="../gui/xwin_kill_preview_background_widget.cpp" line="152"/>
        <source>Click the application you want to end</source>
        <translation>Clic en la aplicación que quiere cerrar</translation>
    </message>
</context>
<context>
    <name>Process.Graph.Title</name>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="183"/>
        <location filename="../gui/mem_detail_view_widget.cpp" line="25"/>
        <location filename="../gui/mem_stat_view_widget.cpp" line="107"/>
        <location filename="../memory_monitor.cpp" line="177"/>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="95"/>
        <location filename="../gui/netif_item_view_widget.cpp" line="121"/>
        <source>Receive</source>
        <translation>Recibido</translation>
    </message>
</context>
<context>
    <name>Process.Graph.View</name>
    <message>
        <location filename="../compact_cpu_monitor.cpp" line="233"/>
        <location filename="../cpu_monitor.cpp" line="233"/>
        <location filename="../cpu_monitor.cpp" line="242"/>
        <location filename="../gui/cpu_detail_widget.cpp" line="371"/>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="182"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="153"/>
        <source>Disk read</source>
        <translation>Lectura del disco</translation>
    </message>
    <message>
        <location filename="../compact_disk_monitor.cpp" line="154"/>
        <source>Disk write</source>
        <translation>Escritura del disco</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="191"/>
        <location filename="../memory_monitor.cpp" line="203"/>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="203"/>
        <location filename="../compact_memory_monitor.cpp" line="210"/>
        <location filename="../gui/mem_stat_view_widget.cpp" line="115"/>
        <location filename="../memory_monitor.cpp" line="214"/>
        <location filename="../memory_monitor.cpp" line="221"/>
        <source>Swap</source>
        <translation>Intercambio</translation>
    </message>
    <message>
        <location filename="../compact_memory_monitor.cpp" line="204"/>
        <location filename="../memory_monitor.cpp" line="215"/>
        <source>Not enabled</source>
        <translation>Inhabilitado</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="158"/>
        <location filename="../network_monitor.cpp" line="216"/>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="163"/>
        <location filename="../network_monitor.cpp" line="221"/>
        <source>Upload</source>
        <translation>Subida</translation>
    </message>
    <message>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="184"/>
        <location filename="../gui/netif_detail_view_widget.cpp" line="28"/>
        <location filename="../network_monitor.cpp" line="198"/>
        <source>Network</source>
        <translation>Red</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="160"/>
        <location filename="../network_monitor.cpp" line="218"/>
        <source>Total Received</source>
        <translation>Total recibido</translation>
    </message>
    <message>
        <location filename="../compact_network_monitor.cpp" line="165"/>
        <location filename="../network_monitor.cpp" line="223"/>
        <source>Total Sent</source>
        <translation>Total enviado</translation>
    </message>
    <message>
        <location filename="../gui/netif_item_view_widget.cpp" line="104"/>
        <location filename="../gui/netif_item_view_widget.cpp" line="130"/>
        <source>Send</source>
        <translation>Enviado</translation>
    </message>
    <message>
        <location filename="../gui/block_dev_detail_view_widget.cpp" line="21"/>
        <location filename="../gui/detail_view_stacked_widget.cpp" line="185"/>
        <source>Disks</source>
        <translation>Discos</translation>
    </message>
</context>
<context>
    <name>Process.Loading</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="67"/>
        <source>Loading</source>
        <translation>Cargando</translation>
    </message>
</context>
<context>
    <name>Process.Priority</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="633"/>
        <location filename="../process/process.cpp" line="55"/>
        <source>Very high</source>
        <translation>Muy alto</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="641"/>
        <location filename="../process/process.cpp" line="56"/>
        <source>High</source>
        <translation>Alto</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="649"/>
        <location filename="../process/process.cpp" line="57"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="657"/>
        <location filename="../process/process.cpp" line="58"/>
        <source>Low</source>
        <translation>Regular</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="665"/>
        <location filename="../process/process.cpp" line="59"/>
        <source>Very low</source>
        <translation>Bajo</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="673"/>
        <location filename="../process/process.cpp" line="60"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location filename="../process/process.cpp" line="61"/>
        <source>Invalid</source>
        <translation>Inválido</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="199"/>
        <source>PID: %1, Error: [%2] %3</source>
        <translation>PID: %1, Error: [%2] %3</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="156"/>
        <location filename="../process/process_db.cpp" line="196"/>
        <source>Failed to change process priority</source>
        <translation>No se modificó la prioridad del proceso</translation>
    </message>
</context>
<context>
    <name>Process.Show.Mode</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="61"/>
        <source>Applications</source>
        <translation>Aplicaciones</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="63"/>
        <source>My processes</source>
        <translation>Mis procesos</translation>
    </message>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="65"/>
        <source>All processes</source>
        <translation>Todos los procesos</translation>
    </message>
</context>
<context>
    <name>Process.Signal</name>
    <message>
        <location filename="../process/process_db.cpp" line="267"/>
        <source>Failed to pause process</source>
        <translation>No se ha podido detener el proceso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="270"/>
        <source>Failed to resume process</source>
        <translation>No se reanudó el proceso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="273"/>
        <source>Failed to kill process</source>
        <translation>Fallo la eliminación del proceso</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="276"/>
        <source>Unknown error</source>
        <translation>Error desconocido</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="337"/>
        <source>Failed in sending signal to process</source>
        <translation>Falló en el envío de la señal para procesar</translation>
    </message>
    <message>
        <location filename="../process/process_db.cpp" line="264"/>
        <source>Failed to end process</source>
        <translation>No se pudo terminar el proceso</translation>
    </message>
</context>
<context>
    <name>Process.Summary</name>
    <message>
        <location filename="../gui/process_page_widget.cpp" line="58"/>
        <source>(%1 applications and %2 processes are running)</source>
        <translation>(%1 aplicaciones y %2 procesos en ejecución)</translation>
    </message>
</context>
<context>
    <name>Process.Table</name>
    <message>
        <location filename="../model/process_table_model.cpp" line="269"/>
        <source>No response</source>
        <translation>No responde</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.cpp" line="275"/>
        <source>Suspend</source>
        <translation>Suspendido</translation>
    </message>
    <message>
        <location filename="../process/process_name.cpp" line="90"/>
        <location filename="../process/process_name.cpp" line="99"/>
        <location filename="../process/process_name.cpp" line="104"/>
        <source>Tray</source>
        <translation>Bandeja</translation>
    </message>
</context>
<context>
    <name>Process.Table.Context.Menu</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="680"/>
        <source>View command location</source>
        <translation>Ver ubicación del comando</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="83"/>
        <location filename="../gui/process_table_view.cpp" line="684"/>
        <source>Properties</source>
        <translation>Propiedades</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="66"/>
        <location filename="../gui/process_table_view.cpp" line="608"/>
        <source>End process</source>
        <translation>Terminar proceso</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="78"/>
        <location filename="../gui/process_table_view.cpp" line="620"/>
        <source>Resume process</source>
        <translation>Reanudar proceso</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="89"/>
        <location filename="../gui/process_table_view.cpp" line="691"/>
        <source>Kill process</source>
        <translation>Matar proceso</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="627"/>
        <source>Change priority</source>
        <translation>Cambiar prioridad</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="72"/>
        <location filename="../gui/process_table_view.cpp" line="614"/>
        <source>Suspend process</source>
        <translation>Suspender proceso</translation>
    </message>
</context>
<context>
    <name>Process.Table.Custom.Priority.Dialog</name>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1052"/>
        <source>Custom Priority</source>
        <translation>Prioridad personalizada</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1085"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../gui/process_table_view.cpp" line="1087"/>
        <source>Change</source>
        <comment>button</comment>
        <translation>Cambiar</translation>
    </message>
</context>
<context>
    <name>Process.Table.Header</name>
    <message>
        <location filename="../model/process_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="18"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="22"/>
        <source>Memory</source>
        <translation>Memoria</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="32"/>
        <source>Disk write</source>
        <translation>Escritura del disco</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="30"/>
        <source>Disk read</source>
        <translation>Lectura del disco</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="28"/>
        <source>Download</source>
        <translation>Descarga</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="26"/>
        <source>Upload</source>
        <translation>Subida</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="34"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="20"/>
        <source>User</source>
        <translation>Usuario</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="36"/>
        <source>Nice</source>
        <translation>NI</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="38"/>
        <source>Priority</source>
        <translation>Prioridad</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="23"/>
        <source>Shared memory</source>
        <translation>Memoria compartida</translation>
    </message>
    <message>
        <location filename="../model/process_table_model.h" line="24"/>
        <source>Virtual memory</source>
        <translation>Memoria virtual</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../system/cpu_set.cpp" line="426"/>
        <source>Not support</source>
        <translation>No compatible</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="10"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="11"/>
        <source>System Protection</source>
        <translation>Protección del sistema</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="12"/>
        <source>Show warnings when the usage exceeds the thresholds</source>
        <translation>Mostrar avisos cuando el uso supera los umbrales</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="13"/>
        <source>CPU warning threshold (%)</source>
        <translation>Umbral de advertencia de la CPU (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="14"/>
        <source>Memory warning threshold (%)</source>
        <translation>Umbral de advertencia de memoria (%)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="15"/>
        <source>Warning interval (min)</source>
        <translation>Intervalo de aviso (min)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/settingsdialog.cpp" line="16"/>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
</context>
<context>
    <name>Service.Action.Set.Startup.Mode</name>
    <message>
        <location filename="../service/service_manager.cpp" line="342"/>
        <source>Failed to set service startup type</source>
        <translation>Error al establecer el tipo de inicio del servicio</translation>
    </message>
    <message>
        <location filename="../service/service_manager.cpp" line="408"/>
        <source>Error: Failed to set service startup type due to the crashed sub process.</source>
        <translation>Error: Falla al establecer el tipo de inicio del servicio debido al subproceso bloqueado.</translation>
    </message>
</context>
<context>
    <name>Service.Instance.Name.Dialog</name>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="157"/>
        <location filename="../gui/system_service_table_view.cpp" line="224"/>
        <location filename="../gui/system_service_table_view.cpp" line="292"/>
        <source>Service instance name</source>
        <translation>Nombre de instancia del servicio</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="38"/>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
    <message>
        <location filename="../gui/service_name_sub_input_dialog.cpp" line="39"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>Service.Table.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="118"/>
        <location filename="../gui/system_service_table_view.cpp" line="562"/>
        <source>Refresh</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="103"/>
        <location filename="../gui/system_service_table_view.cpp" line="542"/>
        <source>Start</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="108"/>
        <location filename="../gui/system_service_table_view.cpp" line="547"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="113"/>
        <location filename="../gui/system_service_table_view.cpp" line="552"/>
        <source>Restart</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="558"/>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="559"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../gui/system_service_table_view.cpp" line="557"/>
        <source>Startup type</source>
        <translation>Tipo de inicio</translation>
    </message>
</context>
<context>
    <name>Service.Table.Header</name>
    <message>
        <location filename="../model/system_service_table_model.h" line="16"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="18"/>
        <source>Load</source>
        <translation>Cargar</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="23"/>
        <source>Sub</source>
        <translation>Ejecución</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="30"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="32"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="27"/>
        <source>Startup Type</source>
        <translation>Tipo de inicio</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="21"/>
        <source>Start State</source>
        <translation>Estado de inicio</translation>
    </message>
    <message>
        <location filename="../model/system_service_table_model.h" line="25"/>
        <source>Start Tactic</source>
        <translation>Táctica de inicio</translation>
    </message>
</context>
<context>
    <name>SystemProtectionSetting</name>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="132"/>
        <source>Settings</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="165"/>
        <source>(Modifiable)</source>
        <translation>(Modificable)</translation>
    </message>
    <message>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="278"/>
        <location filename="../gui/dialog/systemprotectionsetting.cpp" line="387"/>
        <source>Range: %1-%2</source>
        <translation>Rango: %1-%2</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Context.Menu</name>
    <message>
        <location filename="../common/common.cpp" line="59"/>
        <location filename="../gui/main_window.cpp" line="129"/>
        <source>Force end application</source>
        <translation>Forzar cierre de aplicación</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="147"/>
        <source>Expand</source>
        <translation>Expandida</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="150"/>
        <source>Compact</source>
        <translation>Compacta</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="142"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Search</name>
    <message>
        <location filename="../common/common.cpp" line="44"/>
        <location filename="../gui/toolbar.cpp" line="95"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
</context>
<context>
    <name>Title.Bar.Switch</name>
    <message>
        <location filename="../common/common.cpp" line="53"/>
        <location filename="../gui/main_window.cpp" line="224"/>
        <location filename="../gui/main_window.cpp" line="235"/>
        <location filename="../gui/toolbar.cpp" line="45"/>
        <source>Processes</source>
        <translation>Procesos</translation>
    </message>
    <message>
        <location filename="../common/common.cpp" line="98"/>
        <location filename="../gui/main_window.cpp" line="224"/>
        <location filename="../gui/main_window.cpp" line="235"/>
        <location filename="../gui/main_window.cpp" line="245"/>
        <location filename="../gui/toolbar.cpp" line="53"/>
        <source>Services</source>
        <translation>Servicios</translation>
    </message>
    <message>
        <location filename="../gui/main_window.cpp" line="245"/>
        <location filename="../gui/toolbar.cpp" line="60"/>
        <source>Users</source>
        <translation>Usuarios</translation>
    </message>
</context>
<context>
    <name>User.Account.Operation</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="102"/>
        <source>Edit account information</source>
        <translation>Editar información de la cuenta</translation>
    </message>
</context>
<context>
    <name>User.Account.Type</name>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="152"/>
        <source>Administrator</source>
        <translation>Administrador</translation>
    </message>
    <message>
        <location filename="../gui/accounts_widget.cpp" line="152"/>
        <source>Standard User</source>
        <translation>Usuario estándar</translation>
    </message>
</context>
</TS>
